/************************************************/
/*                                              */
/*  UniMail Statistics Converter, Version 1.00  */
/*  Copyright  (c)  1997  by  Vadim Rumyantsev  */
/*  Tested  with   2/REXX  and  Personal  REXX  */
/*                                              */
/************************************************/

parse source system .
parse arg statfile ixf rest

numeric digits 10

say

if ixf = '' | rest <> '' then do
  say 'Usage:  UNICONV statfile ixffile'
  say '        statfile - UniMail statistics file'
  say '        ixffile  - PC/IXF file'
  exit 16
end

if system = 'OS/2' then 
  call rxfuncadd sysfiledelete, rexxutil, sysfiledelete

do until (rundate = date(s))
  rundate = date(s)
  parse value time(n) with hh ':' mm ':' ss
  runtime = hh||mm||ss
end

hdr = charin(statfile,, 26)
if length(hdr) <> 26 then do
  say statfile 'not found'
  exit 8
end

sign = substr(hdr, 1, 2)
addr = substr(hdr, 3, 16)
sort = substr(hdr, 19, 4)
crtd = substr(hdr, 23, 4)

if sign <> 'AF' then do
  say 'Invalid signature in' statfile
  exit 8
end

say 'Statistics file created' s2dt(crtd) 'by' s2ad(addr)
if sort <> '00000000'x then
  say 'Sorted' s2dt(sort)
say

select
  when (system = 'OS/2') then
    call sysfiledelete ixf
  when (system = 'PCDOS') then
    call dosdel ixf
  otherwise
    '@if exist' ixf 'del' ixf
end

codepage = '00850'

ixfhrecl = '000051'
ixfhrect = 'H'
ixfhid   = 'IXF'
ixfhvers = '0001'
ixfhprod = 'UNICNV 01.00'
ixfhdate = rundate
ixfhtime = runtime
ixfhhcnt = '00006'
ixfhsbcp = codepage
ixfhdbcp = '00000'
ixfhfil1 = '  '

call charout ixf, ixfhrecl||ixfhrect||ixfhid||ixfhvers||ixfhprod||,
                  ixfhdate||ixfhtime||ixfhhcnt||ixfhsbcp||ixfhdbcp||ixfhfil1

ixftrecl = '000086'
ixftrect = 'T'
ixftnaml = '10'
ixftname = left('STATISTICS', 18)
ixftqual = 'UNIMAIL '
ixftsrc  = copies(' ', 12)
ixftdata = 'C'
ixftform = 'M'
ixftmfrm = 'PC   '
ixftloc  = 'I'
ixftccnt = '00004'
ixftfil1 = '  '
ixftdesc = copies(' ', 30)

call charout ixf, ixftrecl||ixftrect||ixftnaml||ixftname||ixftqual||,
                  ixftsrc||ixftdata||ixftform||ixftmfrm||ixftloc||,
                  ixftccnt||ixftfil1||ixftdesc

call c_record 'CATEGORY', 500, '00000',  2,  1,  'Y'
call c_record 'ADDRESS',  452, codepage, 32, 3,  'Y'
call c_record 'MESSAGES', 496, '00000',  4,  35, 'N'
call c_record 'BYTES',    496, '00000',  4,  39, 'N'

ixfdrecl = '000050'  
ixfdrect = 'D'
ixfdrid  = '001'
ixfdfil1 = '    '

do n = 0 by 1 while (chars(statfile)<>0)

  stt = charin(statfile,, 26)
  cat = substr(stt, 1, 2)
  adr = s2ad(substr(stt, 3, 16))
  bts = substr(stt, 19, 4)
  mss = substr(stt, 23, 4)

  ixfdcols = cat||left(adr, 32)||mss||bts

  call charout ixf, ixfdrecl||ixfdrect||ixfdrid||ixfdfil1||ixfdcols

end

say n 'records converted'

parse value filespec('N', ixf) with ixft '.'
parse var ixft ixft 19
if \ datatype(ixft, 'A') | pos(left(ixft, 1), xrange('0','9')) <> 0 then
  ixft = 'table'

say
say 'Import command example (for DB2 CAE):'
say "IMPORT FROM '"ixf"' OF IXF MODIFIED BY FORCEIN CREATE INTO" ixft

exit


c_record:

  ixfcrecl = '000084'
  ixfcrect = 'C'
  ixfcnaml = right(length(arg(1)), 2, '0')
  ixfcname = left(arg(1), 18)
  ixfcnull = 'N'
  ixfcslct = 'Y'
  ixfckey  = arg(6)
  ixfcclas = 'R'
  ixfctype = arg(2)
  ixfcsbcp = arg(3)
  ixfcdbcp = '00000'
  ixfcleng = right(arg(4), 5, '0')
  ixfcdrid = '001'
  ixfcposn = right(arg(5), 6, '0')
  ixfcdesc = copies(' ', 30)
  ixfcndim = '00'

  call charout ixf, ixfcrecl||ixfcrect||ixfcnaml||ixfcname||ixfcnull||,
                    ixfcslct||ixfckey||ixfcclas||ixfctype||ixfcsbcp||,
                    ixfcdbcp||ixfcleng||ixfcdrid||ixfcposn||ixfcdesc||ixfcndim

return



s2ad: procedure

  s = arg(1)

  a = c2d(reverse(substr(s, 1, 2)))':' ||,
      c2d(reverse(substr(s, 3, 2)))'/' ||,
      c2d(reverse(substr(s, 5, 2)))
  p = c2d(reverse(substr(s, 7, 2)))
  if p <> 0 then
    a = a'.'p
  d = substr(s, 9)
  if pos('00'x, d) <> 0 then
    d = left(d, pos('00'x, d) - 1)
  if d <> '' then
    a = a'@'d

return a



s2dt: procedure

  s = arg(1)

  t = x2b(c2x(reverse(s)))

  yer = substr(t, 1, 7)
  mon = substr(t, 8, 4)
  day = substr(t, 12, 5)
  hrs = substr(t, 17, 5)
  min = substr(t, 22, 6)
  sec = substr(t, 28, 5)

  d = right(x2d(b2x(day)),2,'0')'.' ||,
      right(x2d(b2x(mon)),2,'0')'.' ||,
      x2d(b2x(yer))+1980,
      right(x2d(b2x(hrs)),2,'0')':' ||,
      right(x2d(b2x(min)),2,'0')':' ||,
      right(x2d(b2x(sec))*2,2,'0')

return d

