/***********************************************/
/*                                             */
/*  UniMail Statistics Reporter, Version 1.00  */
/*  Copyright (c) 1996-97 by Vadim Rumyantsev  */
/*  Tested  with  2/REXX  and  Personal  REXX  */
/*                                             */
/***********************************************/

parse arg statfile

numeric digits 10

say
say

if statfile = '' then do
  say 'Usage:   UNIREP statfile'
  exit 16
end

hdr = charin(statfile,, 26)
if length(hdr) <> 26 then do
  say statfile 'not found'
  exit 8
end

sign = substr(hdr, 1, 2)
addr = substr(hdr, 3, 8)
sort = substr(hdr, 19, 4)
crtd = substr(hdr, 23, 4)

if sign <> 'AF' then do
  say 'Invalid signature'
  exit 8
end

say 'Statistics.'
say
say 'Created' s2dt(crtd) 'by' s2ad(addr)
if sort <> '00000000'x then
  say 'Sorted' s2dt(sort)
say

catlist = ''

do while (chars(statfile)<>0)

  stt = charin(statfile,, 26)
  cat = c2d(reverse(substr(stt, 1, 2)))
  adr = substr(stt, 3, 8)
  bts = c2d(reverse(substr(stt, 19, 4)))
  fls = c2d(reverse(substr(stt, 23, 4)))

  if wordpos(cat, catlist) = 0 then do
    catlist = catlist cat
    reclist.cat.tot = 0
  end

  n = reclist.cat.tot + 1
  reclist.cat.tot = n
  reclist.cat.rec.n.sttadr = adr
  reclist.cat.rec.n.totalb = bts
  reclist.cat.rec.n.totaln = fls

end

do i = words(catlist) to 2 by -1
  do j = 1 to i-1
    w1 = word(catlist, j)
    w2 = word(catlist, j+1)
    if w1 > w2 then do
      p1 = wordindex(catlist, j)
      p2 = wordindex(catlist, j+2)
      if p2 = 0 then
        p2 = length(catlist) + 1
      catlist = left(catlist, p1-1) || w2 w1 substr(catlist, p2)
    end
  end
end

do i = 1 to words(catlist)
  cat = word(catlist, i)
  say
  say 'Category' cat
  say
  call heapsort cat
  do j = 1 to reclist.cat.tot
    say left(s2ad(reclist.cat.rec.j.sttadr), 20),
        right(reclist.cat.rec.j.totalb, 10),
        right(reclist.cat.rec.j.totaln, 10)
  end
  say
end

exit



s2ad: procedure

  parse arg s

  a = c2d(reverse(substr(s, 1, 2)))':' ||,
      c2d(reverse(substr(s, 3, 2)))'/' ||,
      c2d(reverse(substr(s, 5, 2)))
  p = c2d(reverse(substr(s, 7, 2)))
  if p <> 0 then
    a = a'.'p

return a



s2dt: procedure

  parse arg s

  t = x2b(c2x(reverse(s)))

  yer = substr(t, 1, 7)
  mon = substr(t, 8, 4)
  day = substr(t, 12, 5)
  hrs = substr(t, 17, 5)
  min = substr(t, 22, 6)
  sec = substr(t, 28, 5)

  d = right(x2d(b2x(day)),2,'0')'.' ||,
      right(x2d(b2x(mon)),2,'0')'.' ||,
      x2d(b2x(yer))+1980,
      right(x2d(b2x(hrs)),2,'0')':' ||,
      right(x2d(b2x(min)),2,'0')':' ||,
      right(x2d(b2x(sec))*2,2,'0')

return d



heapsort: procedure expose reclist.

  parse arg cat

  l = reclist.cat.tot%2 + 1; r = reclist.cat.tot
  do while (l > 1)
    l = l-1
    call shift cat, l, r
  end
  do while (r > 1)
    x.sttadr = reclist.cat.rec.1.sttadr
    x.totalb = reclist.cat.rec.1.totalb
    x.totaln = reclist.cat.rec.1.totaln
    reclist.cat.rec.1.sttadr = reclist.cat.rec.r.sttadr
    reclist.cat.rec.1.totalb = reclist.cat.rec.r.totalb
    reclist.cat.rec.1.totaln = reclist.cat.rec.r.totaln
    reclist.cat.rec.r.sttadr = x.sttadr
    reclist.cat.rec.r.totalb = x.totalb
    reclist.cat.rec.r.totaln = x.totaln
    r = r-1
    call shift cat, l, r
 end

return



shift: procedure expose reclist.

  parse arg cat, l, r

  i = l; j = 2*l;
  x.sttadr = reclist.cat.rec.l.sttadr
  x.totalb = reclist.cat.rec.l.totalb
  x.totaln = reclist.cat.rec.l.totaln
  j1 = j+1
  if j < r & reclist.cat.rec.j.totalb > reclist.cat.rec.j1.totalb then
    j = j1
  do while (j <= r & x.totalb > reclist.cat.rec.j.totalb)
    reclist.cat.rec.i.sttadr = reclist.cat.rec.j.sttadr
    reclist.cat.rec.i.totalb = reclist.cat.rec.j.totalb
    reclist.cat.rec.i.totaln = reclist.cat.rec.j.totaln
    i = j; j = 2*j
    j1 = j+1
    if j < r & reclist.cat.rec.j.totalb > reclist.cat.rec.j1.totalb then
      j = j1
  end
  reclist.cat.rec.i.sttadr = x.sttadr
  reclist.cat.rec.i.totalb = x.totalb
  reclist.cat.rec.i.totaln = x.totaln

return

